@@ -1,8 +1,8 @@
 from .asset import Asset
 from .buffer import Buffer
 from .decision_gate import DecisionGate
-from .machine import Machine, MachineStatusTracker
-from .maintainer import Maintainer
+from .machine import Machine
+from .maintainer import Maintainer, Maintainable
 from .part import Part
 from .sink import Sink
 from .source import Source
